@@ -1761,7 +1761,7 @@ protected:
 	uint32 tseq;
 	volatile unsigned children;
 	bool offhook, dtmf, answered, starting, holding;
-	time_t exittimer, starttime;
+	time_t audiotimer, starttime;
 	interface_t iface;
 	bridge_t bridge;
 	calltype_t type;
