@@ -1011,6 +1011,24 @@ bool BayonneSession::stateRecord(Event *event)
 {
 	char evtmsg[65];
 	char key;
+	time_t now;
+
+        switch(event->id)
+        {
+        case ENTER_STATE:
+                time(&audiotimer);
+                break;
+        case STOP_DISCONNECT:
+        case STOP_SCRIPT:
+        case CALL_DISCONNECT:
+        case CALL_FAILURE:
+                time(&now);
+                if(now - audiotimer > 3)
+                        break;
+                if(state.audio.total < 30000)
+                        break;
+                remove(state.audio.list[0]);
+        }
 
         if(enterRecord(event))
                 return true;
@@ -1362,6 +1380,7 @@ bool BayonneSession::stateIdle(Event *event)
 	case LINE_WINK:
 	case LINE_DISCONNECT:
 	case STOP_DISCONNECT:
+	case CALL_DISCONNECT:
 	case CANCEL_CHILD:
 	case STOP_SCRIPT:
 	case EXIT_THREAD:
