@@ -37,6 +37,37 @@ void BayonneTSession::sysHangup(const char *tsid)
 		slog.error("libexec hangup failed; tsid=%s", tsid);
 }	
 
+void BayonneTSession::sysPost(const char *sid, char *id, const char *value)
+{
+        Event event;
+
+        char buf[128];
+        const char *cp;
+        char *up;
+
+        enter();
+        if(stricmp(var_sid, sid))
+        {
+                slog.error("libexec call id %s invalid", sid);
+                leave();
+                return;
+        }
+        snprintf(buf, sizeof(buf), "posted:%s", id);
+        up = buf;  
+        while(*up)
+        {
+                if(*up == '_')
+                        *up = '.';
+                ++up;
+        }
+        setSymbol(buf + 7, value);
+        memset(&event, 0, sizeof(event));
+        event.id = POST_LIBEXEC;
+        event.name = buf;  
+	postEvent(&event);
+	leave();
+}
+
 void BayonneTSession::sysVar(const char *tsid, char *id, const char *value, int size)
 {
         char buf[512];
@@ -109,6 +140,11 @@ void BayonneTSession::sysInput(const char *tsid, char *tok)
 		event.libexec.tid = tsid;
 		memset(&state.input, 0, sizeof(state.input));
 		state.timeout = timeout;
+		state.input.interdigit = timeout;
+		if(exitkeys && *exitkeys)
+			state.input.lastdigit = 800;
+		else
+			state.input.lastdigit = timeout;
 		state.input.count = count;
 		state.input.exit = exitkeys;		
 		postEvent(&event);
