@@ -101,7 +101,7 @@ static Keydata::Define server[] = {
 	{"state", "init"},
 	{"logging", "warn"},
 	{"monitoring", "tcp"},
-	{"binding", "ivrscript1"},
+	{"binding", "default"},
 	{NULL, NULL}};
 
 static Keydata::Define engine[] = {
@@ -539,7 +539,6 @@ retry:
         if(!strnicmp("--", option, 2))
                 ++option;
 
-#ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-driver=", 8))
 	{
 		keyengine.setValue("driver", option + 8);
@@ -554,6 +553,7 @@ retry:
                 goto retry;
         }  
 
+#ifdef	HAVE_TESTING
         if(!strnicmp(option, "-test=", 6))
         {
 		testConfig(argv0);
@@ -602,7 +602,8 @@ retry:
                 ++argv;
                 goto retry;
         }
-            
+#endif            
+
 	if(!stricmp(option, "-check"))
 	{
 		keyserver.setValue("logging", "debug");
@@ -610,7 +611,6 @@ retry:
 		++argv;
 		goto retry;
 	}
-#endif
 
 	if(!strnicmp(option, "-vvv", 4))
 	{
@@ -644,7 +644,6 @@ retry:
 		goto retry;
 	}
 
-#ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-voice=", 7))
 	{
 		keyserver.setValue("voice", option + 7);
@@ -667,6 +666,7 @@ retry:
                 goto retry;
         }
 
+#ifdef	HAVE_TESTING
         if(!stricmp(option, "-libexec"))
         {
                 ++argv;
@@ -715,6 +715,7 @@ retry:
                 keyserver.setValue("logging", *(argv++));
                 goto retry;
         }
+#endif
 
         if(!stricmp(option, "-location"))  
         {
@@ -779,7 +780,6 @@ retry:
 		++argv;
                 goto retry;
 	}
-#endif
 
 	if(**argv == '-')
 	{
@@ -823,7 +823,7 @@ skip:
 				else
 					script = NULL;
 
-				runtime.setValue(prefix, *argv);
+				runtime.setValue(*argv, prefix);
 			}
 		}
 		else
