@@ -22,35 +22,6 @@ namespace server {
 using namespace ost;
 using namespace std;
 
-bool Methods::scrBGM(void)
-{
-	const char *bgm = getValue(NULL);
-	BayonneFeeder *feed;
-
-	if(!stricmp(bgm, "off") || !stricmp(bgm, "none") || !*bgm)
-	{
-		setFeeder(NULL);
-		advance();
-		return true;
-	}
-
-	feed = BayonneFeeder::get(bgm);
-	if(!feed)
-	{
-		error("bgm-invalid");
-		return true;
-	}
-
-	if(!setFeeder(feed))
-	{
-		error("bgm-unsupported");
-		return true;
-	}
-
-	advance();
-	return true;
-}
-
 bool Methods::scrTransfer(void)
 {
 	char nbuf[MAX_PATHNAME];
@@ -367,42 +338,6 @@ bool Methods::scrLibexec(void)
 
 #endif
 
-bool Methods::scrEndmenu(void)
-{
-	if(!state.menu)
-	{
-		error("menu-undefined");
-		return true;
-	}
-
-	if(stack > state.stack)
-	{
-		error("menu-overflow");
-		return true;
-	}
-		
-	state.menu = NULL;
-
-	frame[stack].tranflag = false;
-	return scrCleardigits();
-}
-
-bool Methods::scrMenu(void)
-{
-	if(state.menu)
-	{
-		error("menu-defined");
-		return true;
-	}
-
-	state.menu = getName();
-	state.stack = stack;
-
-	frame[stack].tranflag = true;
-
-	return scrCleardigits();
-}
-
 bool Methods::scrCleardigits(void)
 {
 	state.timeout = getTimeoutValue("0");
@@ -480,6 +415,7 @@ bool Methods::scrCollect(void)
 	state.input.var = getOption(NULL);
         state.timeout = getTimeoutKeyword("timeout");
         state.input.interdigit = getTimeoutKeyword("interdigit");
+	state.input.lastdigit = getTimeoutKeyword("lastdigit");
         state.input.format = getKeyword("format");
 	state.input.ignore = getKeyword("ignore");
 
@@ -489,6 +425,9 @@ bool Methods::scrCollect(void)
         if(state.input.interdigit == TIMEOUT_INF)
                 state.input.interdigit = state.timeout;
 
+        if(state.input.lastdigit == TIMEOUT_INF)
+                state.input.lastdigit = state.input.interdigit;   
+
         state.input.exit = getExitKeyword("#");
 
         cp = getKeyword("count");
@@ -533,6 +472,7 @@ bool Methods::scrInput(void)
 	state.input.var = getOption(NULL);
 	state.timeout = getTimeoutKeyword("timeout");
 	state.input.interdigit = getTimeoutKeyword("interdigit");
+	state.input.lastdigit = getTimeoutKeyword("lastdigit");
 	state.input.format = getKeyword("format");
 
 	if(state.timeout == TIMEOUT_INF)
@@ -591,6 +531,14 @@ bool Methods::scrInput(void)
 	if(!state.input.required)
 		state.input.required = state.input.count;
 
+        if(state.input.lastdigit == TIMEOUT_INF)     
+        {
+                if(state.input.exit && *state.input.exit)
+                        state.input.lastdigit = 800; 
+                else
+                        state.input.lastdigit = state.input.interdigit;
+        }
+
 	setState(STATE_INPUT);
 	return false;	
 }
@@ -1032,7 +980,6 @@ bool Methods::scrRecord(void)
         }
 
 	state.audio.list[0] = getValue(NULL);
-
 	state.audio.mode = Audio::modeCreate;
 	if(audio.offset)
 		state.audio.mode = Audio::modeWrite;
